@@ -17,7 +17,9 @@ class ConfigOption(click.types.StringParamType):
     help='Configuration file. (default = r3build.toml)',
     type=ConfigOption(),
 )
-@click.option('-v', '--verbose', help='Verbose mode (equivalent to `log.all = true` in config)', is_flag=True)
+@click.option(
+    '-v', '--verbose', help='Verbose mode (equivalent to `log.all = true` in config)', is_flag=True
+)
 @click.option('--list-types', help='List available job types', is_flag=True)
 def main(config, verbose, list_types):
     if list_types:
@@ -29,9 +31,10 @@ def main(config, verbose, list_types):
     r3.run()
 
     try:
-        time.sleep(999999)
-    except KeyboardInterrupt:
-        return
+        while True:
+            time.sleep(999999)
+    finally:
+        r3.close()
 
 
 main()
