@@ -3,7 +3,12 @@ from r3build.cli import R3build
 
 def test_load_jobs():
     d = {
-        'job': [{'name': 'foo', 'type': 'internaltest',},],
+        'job': [
+            {
+                'name': 'foo',
+                'type': 'internaltest',
+            },
+        ],
     }
     r3 = R3build(config_dict=d)
     assert r3.get_job('foo') is not None
