@@ -1,6 +1,6 @@
 import pytest
 
-from r3build.config_class import Processor, ProcMake
+from r3build.config_class import Processor, MakeProcessorConfig
 
 
 def test_simple_validation():
@@ -29,13 +29,13 @@ def test_recursive_validation():
     with pytest.raises(TypeError):
         p.when = 1
 
-    m = ProcMake('make', {'type': 'make'})
+    m = MakeProcessorConfig('make', {'type': 'make'})
 
     # Dict[str, str]
     m.environment = {'foo': '1'}
 
     with pytest.raises(TypeError):
-        m.environment = {0xf00: '1'}
+        m.environment = {0xF00: '1'}
 
     with pytest.raises(TypeError):
         m.environment = 'I AM A DICT!!!!!'
